sqltriples.Query.NegationOfSubjects

Package sqltriples :: Module Query :: Class NegationOfSubjects |
[show private | hide private]
[frames | no frames]

## Class NegationOfSubjects

                         Negation --+
                                    |
    AbstractQuery --+               |
                    |               |
                Query --+           |
                        |           |
                  Results --+       |
                            |       |
                SingleResults --+   |
                                |   |
                         Subjects --+
                                    |
                                   NegationOfSubjects

Method Summary
| `__init__(self, store, result)`
Inherited from Negation
| ``get_query`(self, index)`
| ``get_subquery`(self, parent_columns, parent_index, index, match_first, match_parent, match_child)`
Inherited from SingleResults
| ``_get_results`(self, results)`
Inherited from Results
| ``_get_joins`(self, index)` Add joins where the result needs them: ...
| ``_get_order_column`(self, index)`
| ``_get_order_direction`(self, index)`
| ``_get_order_extent`(self)`
| ``_get_query`(self, select_clause, index, new_index, constraints, constraint_values)` Build the query conditions and return a usable query which starts with the supplied 'select_clause' and which uses the given table 'index' number as qualifier.
Inherited from Query
| ``__getitem__`(self, i)`
| ``__len__`(self)`
| ``__repr__`(self)`
| ``_apply_function`(self, fn, column)`
| ``_ensure`(self)` Ensure the the query has been executed.
| ``_execute`(self)` Execute the query, generated by this object's 'get_query' method, and return the results in a form produced by this object's '_get_results' method.
| ``_get_columns`(self, exposed_columns, index, limited_to)` Return a column selection for the 'exposed_columns' qualified by the given table 'index', optionally limited by the given 'limited_to' sequence of column definitions.
| ``_get_join_constraints`(self, parent_columns, child_columns, parent_index, child_index)`
| ``_get_table`(self, index)`
Inherited from AbstractQuery
| ``_get_exposed_columns`(self)`

Class Variable Summary
Inherited from Subjects
`list` | `exposed_columns` = `[('subject', 'subject_type')]`
Inherited from AbstractQuery
`list` | `table_columns` = `[('subject', 'subject_type', 0), ('predi...`

Generated by Epydoc 2.1 on Sat Sep 30 00:54:37 2006 | http://epydoc.sf.net